import codecs
import os
from pip.download import PipSession
from pip.index import PackageFinder
from pip.req import parse_requirements
from setuptools import setup, find_packages

root_dir = os.path.abspath(os.path.dirname(__file__))
requirements_path = os.path.join(root_dir, 'requirements', 'base.txt')

session = PipSession()
finder = PackageFinder([], [], session=session)
requirements = parse_requirements(requirements_path, finder, session=session)
install_requires = [r.name for r in requirements]

version = '2.1.1'  # Don't forget to update docs/CHANGELOG.rst if you increment the version

on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
if on_rtd:
    # Use specific versions instead
    install_requires = [str(r.req) for r in requirements]

with codecs.open('README.rst', 'r', 'utf-8') as f:
    long_description = f.read()

setup(
    name="sbo-sphinx",
    version=version,
    author="Jeremy Bowman",
    author_email="jbowman@safaribooksonline.com",
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Topic :: Documentation',
        'Topic :: Software Development :: Documentation',
    ],
    description="Sphinx configuration and libraries for Safari Books Online documentation",
    long_description=long_description,
    url='http://github.com/safarijv/sbo-sphinx',
    packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
    include_package_data=True,
    zip_safe=False,
    install_requires=install_requires,
)
